@@ -8,7 +8,7 @@ library(ggplot2)
 library(weathercan)
 
 ## ---------------------------------------------------------------------------------------
-head(stations)
+stations
 
 ## ---------------------------------------------------------------------------------------
 stations_search("Kamloops")
@@ -42,7 +42,6 @@ stn_vector
 
 ## ---------------------------------------------------------------------------------------
 kam <- weather_dl(station_ids = 51423, start = "2016-01-01", end = "2016-02-15")
-                    
 kam
 
 ## ---------------------------------------------------------------------------------------
